# -*- coding: utf-8 -*-
# Part of Odoo. See LICENSE file for full copyright and licensing details.

from . import common
from . import test_event_crm
from . import test_event_event
from . import test_event_security
from . import test_performance
from . import test_wevent_register
